@@ -1,10 +1,14 @@
 import json
+import logging
 from typing import Any, Dict, List, Optional
 
 import requests
 
 from kbbridge.config.constants import AssistantDefaults
 from kbbridge.core.orchestration.models import Credentials, ProcessingConfig
+from kbbridge.integrations.dify.constants import DifyRetrieverDefaults
+
+logger = logging.getLogger(__name__)
 
 
 def format_search_results(results: list) -> dict:
@@ -33,8 +37,8 @@ def format_search_results(results: list) -> dict:
                     segments.append(
                         {"content": content, "document_name": document_name}
                     )
-            except Exception:
-                # Skip problematic records
+            except Exception as e:
+                logger.debug(f"Skipping problematic record: {e}", exc_info=True)
                 continue
 
         return {
@@ -61,14 +65,11 @@ class KnowledgeBaseRetriever:
         self.endpoint = endpoint
         self.api_key = api_key
 
-    def build_metadata_filter(
-        self, *, source_path: str = "", document_name: str = ""
-    ) -> Optional[dict]:
+    def build_metadata_filter(self, *, document_name: str = "") -> Optional[dict]:
         """
         Build metadata filter for retrieval.
 
         Args:
-            source_path: Filter by source path
             document_name: Filter by document name
 
         Returns:
@@ -76,15 +77,6 @@ class KnowledgeBaseRetriever:
         """
         conditions = []
 
-        if source_path.strip():
-            conditions.append(
-                {
-                    "name": "source_path",
-                    "comparison_operator": "contains",
-                    "value": source_path,
-                }
-            )
-
         if document_name.strip():
             conditions.append(
                 {
@@ -106,8 +98,8 @@ class KnowledgeBaseRetriever:
         search_method: str = "hybrid_search",
         does_rerank: bool = True,
         top_k: int = 10,
-        reranking_provider_name: str = "cohere",
-        reranking_model_name: str = "rerank-multilingual-v2.0",
+        reranking_provider_name: Optional[str] = None,
+        reranking_model_name: Optional[str] = None,
         score_threshold_enabled: bool = False,
         metadata_filter: Optional[dict] = None,
         score_threshold: Optional[float] = None,
@@ -122,8 +114,8 @@ class KnowledgeBaseRetriever:
             search_method: Search method (hybrid_search, semantic_search, etc.)
             does_rerank: Whether to rerank results
             top_k: Number of results to return
-            reranking_provider_name: Reranking provider name
-            reranking_model_name: Reranking model name
+            reranking_provider_name: Reranking provider name (defaults to DifyRetrieverDefaults)
+            reranking_model_name: Reranking model name (defaults to DifyRetrieverDefaults)
             score_threshold_enabled: Whether score threshold is enabled
             metadata_filter: Optional metadata filter
             score_threshold: Optional score threshold
@@ -132,6 +124,18 @@ class KnowledgeBaseRetriever:
         Returns:
             Dictionary containing retrieval results or error information
         """
+        # Use DifyRetrieverDefaults if not provided
+        if reranking_provider_name is None:
+            reranking_provider_name = (
+                DifyRetrieverDefaults.RERANKING_PROVIDER_NAME.value
+            )
+        if reranking_model_name is None:
+            reranking_model_name = DifyRetrieverDefaults.RERANKING_MODEL_NAME.value
+
+        # Disable reranking if provider or model is missing/invalid
+        if does_rerank and (not reranking_provider_name or not reranking_model_name):
+            does_rerank = False
+
         url = f"{self.endpoint.rstrip('/')}/v1/datasets/{dataset_id}/retrieve"
         headers = {
             "Authorization": f"Bearer {self.api_key}",
@@ -196,8 +200,12 @@ class KnowledgeBaseRetriever:
                 # Try to extract error content from response
                 try:
                     error_content = e.response.json().get("error", str(e))
-                except:
+                except Exception as json_err:
                     # If JSON parsing fails, use response text
+                    logger.debug(
+                        f"Failed to parse error response as JSON: {json_err}",
+                        exc_info=True,
+                    )
                     error_content = getattr(e.response, "text", str(e))
             elif response:
                 status_code = response.status_code
@@ -347,8 +355,11 @@ class WorkingIntentionExtractor:
                     "updated_query": query,
                 }
 
-        except Exception:
+        except Exception as e:
             # Fallback on error
+            logger.debug(
+                f"Intention extraction failed, using fallback: {e}", exc_info=True
+            )
             return {
                 "success": True,
                 "intention": f"User wants to find information about: {query}",
@@ -378,12 +389,11 @@ class WorkingDatasetProcessor:
 
         for dataset_pair in dataset_pairs:
             dataset_id = dataset_pair["id"]
-            source_path = dataset_pair.get("source_path", "")
 
-            # Use naive approach (simple search)
-            naive_result = self._process_naive_approach(dataset_id, refined_query)
-            if naive_result.get("candidates"):
-                all_candidates.extend(naive_result["candidates"])
+            # Use direct approach (simple search)
+            direct_result = self._process_direct_approach(dataset_id, refined_query)
+            if direct_result.get("candidates"):
+                all_candidates.extend(direct_result["candidates"])
 
             # Use advanced approach (with reranking)
             advanced_result = self._process_advanced_approach(dataset_id, refined_query)
@@ -393,16 +403,15 @@ class WorkingDatasetProcessor:
             dataset_results.append(
                 {
                     "dataset_id": dataset_id,
-                    "source_path": source_path,
-                    "naive_results": naive_result,
+                    "direct_results": direct_result,
                     "advanced_results": advanced_result,
                 }
             )
 
         return dataset_results, all_candidates
 
-    def _process_naive_approach(self, dataset_id: str, query: str) -> Dict[str, Any]:
-        """Process using naive approach (simple search)"""
+    def _process_direct_approach(self, dataset_id: str, query: str) -> Dict[str, Any]:
+        """Process using direct approach (simple search)"""
         retriever = self.components["retriever"]
 
         result = retriever.retrieve(
@@ -419,8 +428,8 @@ class WorkingDatasetProcessor:
                 candidates.append(
                     {
                         "content": item.get("content", ""),
-                        "score": 1.0,  # Naive approach doesn't provide scores
-                        "source": "dify_naive_search",
+                        "score": 1.0,  # Direct approach doesn't provide scores
+                        "source": "dify_direct_search",
                         "metadata": {"document_name": item.get("document_name", "")},
                     }
                 )
@@ -431,14 +440,21 @@ class WorkingDatasetProcessor:
         """Process using advanced approach (with reranking)"""
         retriever = self.components["retriever"]
 
+        # Check if reranking should be enabled based on credentials availability
+        does_rerank = (
+            self.credentials.is_reranking_available() if self.credentials else False
+        )
+
+        # Use DifyRetrieverDefaults for reranking parameters
+        # These are used for Dify's built-in reranking feature
         result = retriever.retrieve(
             dataset_id=dataset_id,
             query=query,
             search_method="hybrid_search",
-            does_rerank=True,
+            does_rerank=does_rerank,
             top_k=5,
-            reranking_provider_name="cohere",
-            reranking_model_name="rerank-multilingual-v2.0",
+            reranking_provider_name=DifyRetrieverDefaults.RERANKING_PROVIDER_NAME.value,
+            reranking_model_name=DifyRetrieverDefaults.RERANKING_MODEL_NAME.value,
         )
 
         candidates = []
@@ -468,8 +484,8 @@ class WorkingResultFormatter:
             return "No relevant information found in the knowledge base."
 
         # Group by source
-        naive_results = [
-            c for c in candidates if c.get("source") == "dify_naive_search"
+        direct_results = [
+            c for c in candidates if c.get("source") == "dify_direct_search"
         ]
         advanced_results = [
             c for c in candidates if c.get("source") == "dify_advanced_search"
@@ -477,9 +493,9 @@ class WorkingResultFormatter:
 
         answer_parts = []
 
-        if naive_results:
+        if direct_results:
             answer_parts.append("**Search Results:**")
-            for i, result in enumerate(naive_results[:3], 1):
+            for i, result in enumerate(direct_results[:3], 1):
                 content = result.get("content", "").strip()
                 if content:
                     answer_parts.append(f"{i}. {content}")
@@ -491,7 +507,7 @@ class WorkingResultFormatter:
             ):  # Top 2 additional results
                 content = result.get("content", "").strip()
                 if content and content not in [
-                    r.get("content", "") for r in naive_results
+                    r.get("content", "") for r in direct_results
                 ]:
                     answer_parts.append(f"{i}. {content}")
 
